# mlb-fantasy
A MLB fantasy league tracker setup using MLB scores

# How To Use
This is now a python package and can be installed as such.  More to come soon on that process.

`mlb-fantasy draft_picks.txt` and it should generate a .xlsx file for us.  This file will have 3 tabs along the bottom for the Draft Picks, the actual MLB Standings from the live data, and the actual Player Standings data based on the MLB Standings and their picks.